rmsen: Random number generation for the MSEN distribution
Description
Random number generation for the MSEN distribution
Usage
rmsen(n, mu = rep(0, d), Sigma, theta = Inf)
Arguments
n
An integer specifying the number of data points to be simulated.
mu
A vector of length d, where d is the dimensionality, representing the mean value.
Sigma
A symmetric positive-definite matrix representing the scale matrix of the distribution.
theta
A number greater than 0 indicating the tailedness parameter.
Value
A list with the following elements:
X
A data matrix with n rows and d columns.
w
A vector of weights of dimension n.
References
Punzo A., and Bagnato L. (2020). Allometric analysis using the multivariate shifted exponential normal distribution.
Biometrical Journal, 62(6), 1525-1543.