rmtin: Random number generation for the MTIN distribution
Description
Random number generation for the MTIN distribution
Usage
rmtin(n, mu = rep(0, d), Sigma, theta = 0.01)
Arguments
n
An integer specifying the number of data points to be simulated.
mu
A vector of length d, where d is the dimensionality, representing the mean value.
Sigma
A symmetric positive-definite matrix representing the scale matrix of the distribution.
theta
A number between 0 and 1 indicating the tailedness parameter.
Value
A list with the following elements:
X
A data matrix with n rows and d columns.
w
A vector of weights of dimension n.
References
Punzo A., and Bagnato L. (2021). The multivariate tail-inflated normal distribution and its application in finance.
Journal of Statistical Computation and Simulation, 91(1), 1-36.